==> workplayerapi-1.0.34.tgz: package/config/logged.js <==
/*
 * [EN]
 * Copyright (C) Kyros Technologies, Inc - All Rights Reserved
 *
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written by Kim Ruan <kimr@kyros.com.br>, April 2018
 *
 *
 * [NR]
 * Copyright (C) Kyros Technologies, Inc - Alle rettigheter reservert
 *
 * Uautorisert kopiering av denne filen, via hvilket som helst medium, er strengt forbudt
 * Egen og konfidensiell
 * Skrevet av Kim Ruan <kimr@kyros.com.br>, April 2018
 *
 *
 * [PT-BR]
 * Copyright (C) Kyros Technologies, Inc - Todos os direitos reservados
 *
 * Cópias não autorizadas deste arquivo, através de qualquer meio é estritamente proibido
 * Confidenciais e proprietários
 * Escrito por Kim Ruan <kimr@kyros.com.br>, Abril 2018
 */

import axios from 'axios';

import { BASE_URL } from './constants';

let currentToken = null;

export function setToken(token) {
    currentToken = token;
}

const logged = axios.create({
    baseURL        : BASE_URL,
    validateStatus : status => { return status < 500 }
});

logged.defaults.headers.post['Content-Type'] = 'application/json';
logged.defaults.headers.get['Content-Type'] = 'application/json';
logged.defaults.timeout = 2500;

logged.interceptors.request.use(request => {
        request.headers.post['x-token'] = currentToken;
        request.headers.get['x-token'] = currentToken;
        return request;
    },
    error => Promise.reject(error)
);

logged.interceptors.response.use(response => {
        return response;
    },
    error => Promise.reject(error)
);

export default logged;

==> workplayerapi-1.0.50.tgz: package/config/logged.js <==
/*
 * [EN]
 * Copyright (C) Kyros Technologies, Inc - All Rights Reserved
 *
 * Unauthorized copying of this file, via any medium is strictly prohibited
 * Proprietary and confidential
 * Written by Kim Ruan <kimr@kyros.com.br>, April 2018
 *
 *
 * [NR]
 * Copyright (C) Kyros Technologies, Inc - Alle rettigheter reservert
 *
 * Uautorisert kopiering av denne filen, via hvilket som helst medium, er strengt forbudt
 * Egen og konfidensiell
 * Skrevet av Kim Ruan <kimr@kyros.com.br>, April 2018
 *
 *
 * [PT-BR]
 * Copyright (C) Kyros Technologies, Inc - Todos os direitos reservados
 *
 * Cópias não autorizadas deste arquivo, através de qualquer meio é estritamente proibido
 * Confidenciais e proprietários
 * Escrito por Kim Ruan <kimr@kyros.com.br>, Abril 2018
 */

import axios from 'axios';

import { PROD, DEV } from './constants';

let currentToken = null;
let currentEnvironment = null;

export function setToken(token) {
    currentToken = token;
}

export function setEnvironment(env) {
    if (env === 'release') currentEnvironment = PROD;
    else currentEnvironment = DEV;
}

const logged = axios.create({
    baseURL        : currentEnvironment,
    validateStatus : status => { return status < 500 }
});

logged.defaults.headers.post['Content-Type'] = 'application/json';
logged.defaults.headers.get['Content-Type'] = 'application/json';
logged.defaults.timeout = 2500;

logged.interceptors.request.use(request => {
        request.headers.post['x-token'] = currentToken;
        request.headers.get['x-token'] = currentToken;
        return request;
    },
    error => Promise.reject(error)
);

logged.interceptors.response.use(response => {
        return response;
    },
    error => Promise.reject(error)
);

export default logged;
